==> mailman-2.1.14-1.tgz: mailman-2.1.14-1/doc/mailman-install/labels.pl <==
# LaTeX2HTML 2002-2-1 (1.71)
# Associate labels original text with physical files.


$key = q/exim3-transport/;
$external_labels{$key} = "$URL/" . q|node19.html|; 
$noresave{$key} = "$nosave";

$key = q/postfix-integration/;
$external_labels{$key} = "$URL/" . q|node13.html|; 
$noresave{$key} = "$nosave";

$key = q/front/;
$external_labels{$key} = "$URL/" . q|node1.html|; 
$noresave{$key} = "$nosave";

$key = q/create-install-dir/;
$external_labels{$key} = "$URL/" . q|node5.html|; 
$noresave{$key} = "$nosave";

$key = q/mail-server/;
$external_labels{$key} = "$URL/" . q|node11.html|; 
$noresave{$key} = "$nosave";

$key = q/qmail-issues/;
$external_labels{$key} = "$URL/" . q|node35.html|; 
$noresave{$key} = "$nosave";

$key = q/troubleshooting/;
$external_labels{$key} = "$URL/" . q|node46.html|; 
$noresave{$key} = "$nosave";

$key = q/site-list/;
$external_labels{$key} = "$URL/" . q|node40.html|; 
$noresave{$key} = "$nosave";

$key = q/customizing/;
$external_labels{$key} = "$URL/" . q|node39.html|; 
$noresave{$key} = "$nosave";

$key = q/building/;
$external_labels{$key} = "$URL/" . q|node46.html|; 
$noresave{$key} = "$nosave";

$key = q/about/;
$external_labels{$key} = "$URL/" . q|node51.html|; 
$noresave{$key} = "$nosave";

$key = q/postfix-virtual/;
$external_labels{$key} = "$URL/" . q|node14.html|; 
$noresave{$key} = "$nosave";

$key = q/bsd-issues/;
$external_labels{$key} = "$URL/" . q|node49.html|; 
$noresave{$key} = "$nosave";

1;


# LaTeX2HTML 2002-2-1 (1.71)
# labels from external_latex_labels array.


$key = q/postfix-integration/;
$external_latex_labels{$key} = q|6.1|; 
$noresave{$key} = "$nosave";

$key = q/exim3-transport/;
$external_latex_labels{$key} = q|6.2|; 
$noresave{$key} = "$nosave";

$key = q/create-install-dir/;
$external_latex_labels{$key} = q|2.2|; 
$noresave{$key} = "$nosave";

$key = q/mail-server/;
$external_latex_labels{$key} = q|6|; 
$noresave{$key} = "$nosave";

$key = q/qmail-issues/;
$external_latex_labels{$key} = q|6.4|; 
$noresave{$key} = "$nosave";

$key = q/troubleshooting/;
$external_latex_labels{$key} = q|14|; 
$noresave{$key} = "$nosave";

$key = q/site-list/;
$external_latex_labels{$key} = q|8|; 
$noresave{$key} = "$nosave";

$key = q/customizing/;
$external_latex_labels{$key} = q|7|; 
$noresave{$key} = "$nosave";

$key = q/building/;
$external_latex_labels{$key} = q|14|; 
$noresave{$key} = "$nosave";

$key = q/postfix-virtual/;
$external_latex_labels{$key} = q|6.1|; 
$noresave{$key} = "$nosave";

$key = q/bsd-issues/;
$external_latex_labels{$key} = q|15.2|; 
$noresave{$key} = "$nosave";

1;

==> mailman-2.1.18rc3.tgz: mailman-2.1.18rc3/doc/mailman-install/labels.pl <==
# LaTeX2HTML 2008 (1.71)
# Associate labels original text with physical files.


$key = q/exim3-transport/;
$external_labels{$key} = "$URL/" . q|node19.html|; 
$noresave{$key} = "$nosave";

$key = q/postfix-integration/;
$external_labels{$key} = "$URL/" . q|node13.html|; 
$noresave{$key} = "$nosave";

$key = q/front/;
$external_labels{$key} = "$URL/" . q|node1.html|; 
$noresave{$key} = "$nosave";

$key = q/create-install-dir/;
$external_labels{$key} = "$URL/" . q|node5.html|; 
$noresave{$key} = "$nosave";

$key = q/mail-server/;
$external_labels{$key} = "$URL/" . q|node11.html|; 
$noresave{$key} = "$nosave";

$key = q/qmail-issues/;
$external_labels{$key} = "$URL/" . q|node35.html|; 
$noresave{$key} = "$nosave";

$key = q/troubleshooting/;
$external_labels{$key} = "$URL/" . q|node46.html|; 
$noresave{$key} = "$nosave";

$key = q/site-list/;
$external_labels{$key} = "$URL/" . q|node40.html|; 
$noresave{$key} = "$nosave";

$key = q/customizing/;
$external_labels{$key} = "$URL/" . q|node39.html|; 
$noresave{$key} = "$nosave";

$key = q/building/;
$external_labels{$key} = "$URL/" . q|node6.html|; 
$noresave{$key} = "$nosave";

$key = q/about/;
$external_labels{$key} = "$URL/" . q|node51.html|; 
$noresave{$key} = "$nosave";

$key = q/postfix-virtual/;
$external_labels{$key} = "$URL/" . q|node14.html|; 
$noresave{$key} = "$nosave";

$key = q/bsd-issues/;
$external_labels{$key} = "$URL/" . q|node49.html|; 
$noresave{$key} = "$nosave";

1;


# LaTeX2HTML 2008 (1.71)
# labels from external_latex_labels array.


$key = q/postfix-integration/;
$external_latex_labels{$key} = q|6.1|; 
$noresave{$key} = "$nosave";

$key = q/exim3-transport/;
$external_latex_labels{$key} = q|6.2|; 
$noresave{$key} = "$nosave";

$key = q/create-install-dir/;
$external_latex_labels{$key} = q|2.2|; 
$noresave{$key} = "$nosave";

$key = q/mail-server/;
$external_latex_labels{$key} = q|6|; 
$noresave{$key} = "$nosave";

$key = q/qmail-issues/;
$external_latex_labels{$key} = q|6.4|; 
$noresave{$key} = "$nosave";

$key = q/troubleshooting/;
$external_latex_labels{$key} = q|14|; 
$noresave{$key} = "$nosave";

$key = q/site-list/;
$external_latex_labels{$key} = q|8|; 
$noresave{$key} = "$nosave";

$key = q/customizing/;
$external_latex_labels{$key} = q|7|; 
$noresave{$key} = "$nosave";

$key = q/building/;
$external_latex_labels{$key} = q|3|; 
$noresave{$key} = "$nosave";

$key = q/postfix-virtual/;
$external_latex_labels{$key} = q|6.1|; 
$noresave{$key} = "$nosave";

$key = q/bsd-issues/;
$external_latex_labels{$key} = q|15.2|; 
$noresave{$key} = "$nosave";

1;
